import request from '@/utils/request'

// 查询选择页面列表
export function listSelectApp(query) {
  return request({
    url: '/VRdemo/selectApp/list',
    method: 'get',
    params: query
  })
}

// 查询选择页面详细
export function getSelectApp(companyAppId) {
  return request({
    url: '/VRdemo/selectApp/' + companyAppId,
    method: 'get'
  })
}

// 新增选择页面
export function addSelectApp(data) {
  return request({
    url: '/VRdemo/selectApp',
    method: 'post',
    data: data
  })
}

// 修改选择页面
export function updateSelectApp(data) {
  return request({
    url: '/VRdemo/selectApp',
    method: 'put',
    data: data
  })
}

// 删除选择页面
export function delSelectApp(companyAppId) {
  return request({
    url: '/VRdemo/selectApp/' + companyAppId,
    method: 'delete'
  })
}


/** 选择app */
export function enterApp(companyAppId) {
  return request({
    url: '/VRdemo/selectApp/enter/' + companyAppId,
    method: 'get'
  })
}

// 查找可选择的展厅
export function chooseAppList() {
  return request({
    url: '/VRdemo/selectApp/chooseAppList',
    method: 'post'
  })
}

// 企业端选择展厅
export function addCompanyApp(data) {
  return request({
    url: '/VRdemo/selectApp/addCompanyApp',
    method: 'post',
    data: data
  })
}